( cd boot ; rm -rf vmlinux )
( cd boot ; ln -sf vmlinux-2.4.32-gl64070620 vmlinux )
( cd boot ; rm -rf System.map )
( cd boot ; ln -sf System.map-2.4.32-gl64070620 System.map )
( cd boot ; rm -rf config )
( cd boot ; ln -sf config-2.4.32-gl64070620 config )
